.. sectnum::

.. include:: ../../README.rst

pySignalScope function documentation
==================================================
.. currentmodule:: pysignalscope.scope

.. autoclass:: pysignalscope.Channel
   :members: 
   
.. autoclass:: pysignalscope.Scope
   :members: 
     
.. autoclass:: pysignalscope.ImpedanceChannel
   :members:
   
.. autoclass:: pysignalscope.Impedance
   :members:
  
.. automodule:: pysignalscope.functions
   :members:

.. automodule:: pysignalscope.generalplotsettings
   :members:

.. automodule:: pysignalscope.colors
   :members:
